@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.36'; # VERSION
+our $DATE = '2015-09-22'; # DATE
+our $VERSION = '0.37'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,7 +65,7 @@ sub _default_completion {
     # to the routine)
     if ($word =~ m!\A(~[^/]*)/!) {
         $log->tracef("[comp][compgl] completing file, path=<%s>", $word);
-        $fres = {words=>Complete::Util::complete_file(word=>$word),
+        $fres = {words=>Complete::File::complete_file(word=>$word),
                  path_sep=>'/'};
         goto RETURN_RES;
     }
@@ -587,7 +587,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.36 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-09-17.
+This document describes version 0.37 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-09-22.
 
 =head1 SYNOPSIS
 
